@@ -20,9 +20,16 @@ use XML::Twig;
 use Path::Tiny;
 use Config::Model::Itself;
 use Config::Model::Exception;
+use Getopt::Long;
 use experimental qw/postderef signatures/ ;
 
-my $systemd_path = path('/home/domi/debian-dev/systemd-228/man/');
+my %opt;
+GetOptions (\%opt, "from=s") or die("Error in command line arguments\n");
+
+my $systemd_path = path($opt{from});
+die "Can't open directory ".$opt{from}."\n" unless $systemd_path->is_dir;
+
+my $systemd_man_path = $systemd_path->child('man');
 
 Config::Model::Exception::Trace(1);
 
@@ -33,7 +40,7 @@ sub parse_xml ($list, $map) {
     my $file ;
 
     my $desc = sub ($t, $elt) {
-        my $txt = $elt->trimmed_text;
+        my $txt = $elt->text;
         # there's black magic in XML::Twig that trash error message
         # contained in an error object.  So the error must be stringified
         # explicitly before being sent upward
@@ -46,11 +53,29 @@ sub parse_xml ($list, $map) {
     my $manpage = sub ($t, $elt) {
         my $man = $elt->first_child('refentrytitle')->text;
         my $nb = $elt->first_child('manvolnum')->text;
-        $elt->set_text( "L<$man($nb)>");
+        my $url = "https://manpages.debian.org/cgi-bin/man.cgi?query=$man&sektion=$nb&manpath=Debian+unstable+sid";
+        $elt->set_text( qq!L<$man($nb)|"$url">!);
+    };
+
+    my $condition_variable = sub  ($t, $elt) {
+        my @var_list = $elt->children('term') ;
+        my $listitem = $elt->first_child('listitem');
+        my $pre_doc = $listitem->first_child_text('para');
+        my $post_doc = $listitem->last_child_text('para');
+        foreach my $var_elt (@var_list) {
+            my $var_name = $var_elt->text;
+            my ($var_doc_elt) = $listitem->get_xpath(qq!./para/varname[string()="$var_name"]!);
+            #say "condition_variable $var_name found at ",$var_doc_elt->path;
+            my ($name, $extra_info) = split '=', $var_name, 2;
+            say $file->basename(".xml").": class $config_class element $name, trashed $extra_info" if $extra_info;
+            my $desc = join ("\n\n", $pre_doc, $var_doc_elt->parent->text, $post_doc);
+            push $data{element}->@*, [$config_class => $name => $desc => $extra_info];
+        }
     };
 
     my $variable = sub  ($t, $elt) {
-        my $desc = $elt->first_child('listitem')->trimmed_text;
+        return $condition_variable->($t, $elt) if $elt->first_child_text('term') =~ /^Condition/;
+        my $desc = $elt->first_child('listitem')->text;
         $desc =~ s/(\w+)=/C<$1>/g;
 
         foreach my $term_elt ($elt->children('term')) {
@@ -84,7 +109,7 @@ sub parse_xml ($list, $map) {
     );
 
     foreach my $subsystem ($list->@*) {
-        $file = $systemd_path->child("systemd.$subsystem.xml");
+        $file = $systemd_man_path->child("systemd.$subsystem.xml");
         $set_config_class->($subsystem);
         $twig->parsefile($file);
     }
@@ -100,9 +125,14 @@ sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info) {
         autoadd => 1
     );
 
+    # trim description (which is not saved in this sub) to simplify
+    # the regexp below
+    $desc =~ s/[\s\n]+/ /g;
+
     my $value_type
         = $desc =~ /Takes an? (boolean|integer)/ ? $1
         : $desc =~ /Takes time \(in seconds\)/   ? 'integer'
+        : $desc =~ /Takes one of/                ? 'enum'
         : $extra_info =~ /\w\|\w/                ? 'enum'
         :                                          'uniline';
 
@@ -114,10 +144,21 @@ sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info) {
 
     push @load, 'type=leaf', "value_type=$value_type";
 
-    if ($value_type eq 'enum') {
+    if ($extra_info =~ /\w\|\w/) {
         $extra_info =~ s/\|/,/g;
         push @load, "choice=$extra_info";
     }
+    elsif ($desc =~ /Takes one of/) {
+        my ($choices) = ($desc =~ /Takes one of ([^.]+?)(?:\.|to test)/);
+        say "$element found ->$choices<-";
+        $choices =~ s/\(the default\)//g;
+        $choices =~ s/\b(or|and)\b/,/g;
+        $choices =~ s/\s//g;
+        $choices =~ s/C<(\w+)>/$1/g;
+        $choices =~ s/,+/,/g;
+        say "set choice $choices";
+        push @load, qq!choice=$choices!;
+    }
 
     push @load, "min=$min" if defined $min;
     push @load, "max=$max" if defined $max;
@@ -161,13 +202,21 @@ foreach my $config_class ($meta_root->fetch_element('class')->fetch_all_indexes)
 say "Creating systemd model...";
 
 foreach my $config_class (keys $data->{class}->%*) {
-    my $desc = $data->{class}{$config_class};
+    my $desc_ref = $data->{class}{$config_class};
+    my $desc_text = join("\n\n",$desc_ref->@*);
+    $desc_text =~ s/^\s+//gm;
+
+    $desc_text.="\nThis configuration class was generated from systemd documentation.\n"
+        ."by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-man.pl>\n";
     my $steps = "class:$config_class class_description";
-    $meta_root->grab(step => $steps, autoadd => 1)->store(join("\n\n",$desc->@*));
+    $meta_root->grab(step => $steps, autoadd => 1)->store($desc_text);
 
     # TODO: indicates systemd version
     $meta_root->load( steps => [
         qq!class:$config_class generated_by="systemd parse-man.pl"!,
+        qq!copyright:0="2010-2016 Lennart Poettering and others"!,
+        qq!copyright:1="2016 Dominique Dumont"!,
+        qq!license="LGPLv2.1+"!,
         qq!accept:".*" type=leaf value_type=uniline!,
     ]);
 
@@ -181,6 +230,10 @@ foreach my $cdata ($data->{element}->@*) {
     # cleanup one utf8 characters (aka \x{2014}). This can be removed once Config::Model 2.084
     # is released: generated pod will declare utf8 encoding
     $desc =~ s/—/--/g;
+    $desc =~ s/ / /g; # not exactly an underscore
+
+    # cleanup empty lines
+    $desc =~ s/^\s+//gm;
 
     $obj->fetch_element("description")->store($desc);
 }
